@@ -75,13 +75,21 @@ class ImageRecognizer(object):
         else:
             if os.path.isfile(dst_img_file_json):
                 data = json.load(open(dst_img_file_json, "r", encoding="utf-8"))
-                if ((len(data["recognize_text"])<=0) or
+                if ((data.__contains__("recognize_text") == False) or
+                    (len(data["recognize_text"])<=0) or
+                    (data.__contains__("app_name") == False) or
                     (data["app_name"] != app_name) or
+                    (data.__contains__("flag_autocrop") == False) or
                     (data["flag_autocrop"] != self.flag_autocrop) or
+                    (data.__contains__("ratio") == False) or
                     (data["ratio"] != self.ratio) or
+                    (data.__contains__("crop_img_top") == False) or
                     (data["crop_img_top"] != self.top) or
+                    (data.__contains__("crop_img_bottom") == False) or
                     (data["crop_img_bottom"] != self.bottom) or
+                    (data.__contains__("crop_img_left") == False) or
                     (data["crop_img_left"] != self.left) or
+                    (data.__contains__("crop_img_right") == False) or
                     (data["crop_img_right"] != self.right)):
                     os.remove(dst_img_file_json)
         if os.path.isfile(dst_img_file_json) == False:
